couchdb.tools

Package couchdb :: Package tools |

# Package tools

Submodules
couchdb.tools.dump: Utility for dumping a snapshot of a CouchDB database to a multipart MIME file. couchdb.tools.load: Utility for loading a snapshot of a CouchDB database from a multipart MIME file. couchdb.tools.replication_helper: CouchDB `update_notification` script that triggers replication. couchdb.tools.replication_helper_test: Simple functional test for the replication notification trigger

Variables
| __package__ = `None` hash(x)